# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Bundle'
        db.create_table(u'errata_bundle', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('modified', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True, db_index=True)),
            ('bundleid', self.gf('django.db.models.fields.IntegerField')(max_length=32)),
            ('release', self.gf('django.db.models.fields.related.ForeignKey')(related_name='bundles', to=orm['errata.Release'])),
            ('distro', self.gf('django.db.models.fields.related.ForeignKey')(related_name='bundles', to=orm['errata.Distro'])),
        ))
        db.send_create_signal(u'errata', ['Bundle'])

        # Adding unique constraint on 'Bundle', fields ['bundleid', 'release', 'distro']
        db.create_unique(u'errata_bundle', ['bundleid', 'release_id', 'distro_id'])

        # Adding field 'Package.bundle'
        db.add_column(u'errata_package', 'bundle',
                      self.gf('django.db.models.fields.related.ForeignKey')(related_name='packages', null=True, to=orm['errata.Bundle']),
                      keep_default=False)


    def backwards(self, orm):
        # Removing unique constraint on 'Bundle', fields ['bundleid', 'release', 'distro']
        db.delete_unique(u'errata_bundle', ['bundleid', 'release_id', 'distro_id'])

        # Deleting model 'Bundle'
        db.delete_table(u'errata_bundle')

        # Deleting field 'Package.bundle'
        db.delete_column(u'errata_package', 'bundle_id')


    models = {
        u'errata.bundle': {
            'Meta': {'unique_together': "(('bundleid', 'release', 'distro'),)", 'object_name': 'Bundle'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'bundleid': ('django.db.models.fields.IntegerField', [], {'max_length': '32'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'distro': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'bundles'", 'to': u"orm['errata.Distro']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'release': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'bundles'", 'to': u"orm['errata.Release']"})
        },
        u'errata.distro': {
            'Meta': {'unique_together': "(('name', 'release'),)", 'object_name': 'Distro'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '32', 'db_index': 'True'}),
            'release': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'distros'", 'to': u"orm['errata.Release']"})
        },
        u'errata.erratum': {
            'Meta': {'object_name': 'Erratum'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'affected_package': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'errata_affected'", 'symmetrical': 'False', 'to': u"orm['errata.Package']"}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'cve': ('django.db.models.fields.CharField', [], {'max_length': '32', 'db_index': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'max_length': '262000'}),
            'disclosed': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'db_index': 'True'}),
            'fixed_package': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'errata_fixed'", 'symmetrical': 'False', 'to': u"orm['errata.Package']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'jira': ('django.db.models.fields.CharField', [], {'max_length': '32', 'db_index': 'True'}),
            'launchpad': ('django.db.models.fields.CharField', [], {'max_length': '32', 'db_index': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'patch_scenario': ('django.db.models.fields.TextField', [], {'max_length': '262000'}),
            'patch_scenario_disclosed': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'tests': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'errata'", 'null': 'True', 'to': u"orm['errata.Test']"}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'verify_scenario': ('django.db.models.fields.TextField', [], {'max_length': '262000'}),
            'verify_scenario_disclosed': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'zendesk': ('django.db.models.fields.CharField', [], {'max_length': '32', 'db_index': 'True'})
        },
        u'errata.package': {
            'Meta': {'unique_together': "(('name', 'version', 'distro', 'release'),)", 'object_name': 'Package'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'bundle': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'packages'", 'null': 'True', 'to': u"orm['errata.Bundle']"}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'distro': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'packages'", 'to': u"orm['errata.Distro']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'}),
            'release': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'packages'", 'to': u"orm['errata.Release']"}),
            'version': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'})
        },
        u'errata.release': {
            'Meta': {'object_name': 'Release'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'default': "'6.1'", 'unique': 'True', 'max_length': '32', 'db_index': 'True'})
        },
        u'errata.test': {
            'Meta': {'object_name': 'Test'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'db_index': 'True'})
        }
    }

    complete_apps = ['errata']