from django.conf import settings
from django.db import models

class CreateTimeBaseObject(models.Model):
    created = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)
    active = models.BooleanField(default=True, db_index=True)

    class Meta:
        abstract = True

class Test(CreateTimeBaseObject):
    name = models.CharField(max_length=255, db_index=True)

class Release(CreateTimeBaseObject):
    name = models.CharField(max_length=32, db_index=True, unique=True, default='6.1')

class Distro(CreateTimeBaseObject):
    name = models.CharField(max_length=32, db_index=True)
    release = models.ForeignKey(Release, related_name='distros')

    class Meta:
        unique_together = ('name', 'release')

class Bundle(CreateTimeBaseObject):
    bundleid = models.IntegerField(max_length=32)
    release = models.ForeignKey(Release, related_name='bundles')
    distro = models.ForeignKey(Distro, related_name='bundles')

    class Meta:
        unique_together = ('bundleid', 'release', 'distro')

    @property
    def url(self):
        return settings.MIRROR_URL % self.bundleid

class Package(CreateTimeBaseObject):
    name = models.CharField(max_length=255, db_index=True)
    version = models.CharField(max_length=255, db_index=True)
    release = models.ForeignKey(Release, related_name='packages')
    distro = models.ForeignKey(Distro, related_name='packages')
    bundle = models.ForeignKey(Bundle, related_name='packages', null=True)
    git_project = models.CharField(max_length=255, null=True, db_index=True)
    git_commit = models.CharField(max_length=40, null=True, db_index=True)

    class Meta:
        unique_together = ('name', 'version', 'distro', 'release')

class Erratum(CreateTimeBaseObject):
    title = models.CharField(max_length=255)
    description = models.TextField(max_length=262000)
    disclosed = models.BooleanField(default=True, db_index=True)
    security = models.BooleanField(default=False, db_index=True)
    cve = models.CharField(max_length=32, db_index=True, null=True)
    ossa = models.CharField(max_length=32, db_index=True, null=True)
    launchpad = models.CharField(max_length=32, db_index=True)
    zendesk = models.CharField(max_length=32, db_index=True)
    jira = models.CharField(max_length=32, db_index=True)
    patch_scenario_disclosed = models.BooleanField(default=True, db_index=True)
    patch_scenario = models.TextField(max_length=262000)
    verify_scenario_disclosed = models.BooleanField(default=True, db_index=True)
    verify_scenario = models.TextField(max_length=262000)
    tests = models.ForeignKey(Test, related_name='errata', null=True)
    affected_package = models.ManyToManyField(Package, related_name='errata_affected')
    fixed_package = models.ManyToManyField(Package, related_name='errata_fixed')
