from django.test import TestCase
from errata.models import Bundle, Distro, Erratum, Package, Release

class ErratumCreateTestCase(TestCase):
    def setUp(self):
        self.r = Release.objects.create(
            name='test')
        self.d = Distro.objects.create(
            name='Ubuntu', release=self.r)

    def test_erratum_create(self):
        e = Erratum.objects.create(
            title='erratum_title',
            description='erratum_description',
            disclosed=True,
            security=False,
            cve='111-111-111',
            launchpad='123456')

        self.assertEqual(e.title, 'erratum_title')
        self.assertEqual(e.description, 'erratum_description')
        self.assertEqual(e.disclosed, True)
        self.assertEqual(e.security, False)
        self.assertEqual(e.cve, '111-111-111')
        self.assertEqual(e.launchpad, '123456')

    def test_package_create(self):
        e = Erratum.objects.create(
            title='erratum_title',
            description='erratum_description',
            disclosed=True)

        self.assertEqual(e.title, 'erratum_title')
        self.assertEqual(e.description, 'erratum_description')
        self.assertEqual(e.disclosed, True)

        p = Package.objects.create(
            name='blah',
            version='1.0',
            release=self.r,
            distro=self.d)

        e.fixed_package.add(p)

        self.assertEqual(p.name, 'blah')
        self.assertEqual(p.version, '1.0')
        self.assertEqual(p.release, self.r)
        self.assertEqual(p.distro, self.d)

        self.assertEqual(
            e.fixed_package.all()[0], p)
